pub struct AdaptersArg {
pub adapters: Vec<(String, Vec<u8>)>,
}Fields
adapters: Vec<(String, Vec<u8>)>The path to an adapter module to satisfy imports not otherwise bound to WIT interfaces.
An adapter module can be used to translate the wasi_snapshot_preview1
ABI, for example, to one that uses the component model. The first
[NAME=] specified in the argument is inferred from the name of file
specified by MODULE if not present and is the name of the import
module that’s being implemented (e.g. wasi_snapshot_preview1.wasm).
The second part of this argument is the path to the adapter module.